@@ -89,8 +89,8 @@ class NexusWriter:
     ):
         # assumes fast and slow axis vectors have already been converted if needed
         # Scaled center
-        x_scaled = beam_center_xy[0] * (xy_pixel_size[0] / 1000)
-        y_scaled = beam_center_xy[1] * (xy_pixel_size[1] / 1000)
+        x_scaled = beam_center_xy[0] * (xy_pixel_size[0])
+        y_scaled = beam_center_xy[1] * (xy_pixel_size[1])  # let's leave it in mm
         # Detector origin
         det_origin = x_scaled * numpy.array(fast_axis_v) + y_scaled * numpy.array(
             slow_axis_v
@@ -111,8 +111,15 @@ class NexusWriter:
         nxdata = nxentry.create_group("data")
         create_attributes(
             nxdata,
-            ("NX_class", "axes", "signal"),
-            ("NXdata", goniometer.axes[idx], "data"),
+            ("NX_class", "axes", "signal", goniometer.axes[idx] + "_indices"),
+            (
+                "NXdata",
+                goniometer.axes[idx],
+                "data",
+                [
+                    0,
+                ],
+            ),
         )
 
         # If mode = images, create blank image data, else go to events
@@ -266,12 +273,12 @@ class NexusWriter:
         )
         create_attributes(
             fast_pixel,
-            ("depends_on", "offset", "transformation_type", "units", "vector"),
+            ("depends_on", "offset_units", "transformation_type", "units", "vector"),
             (
                 "/entry/instrument/transformations/det_z",
                 offsets[0],
                 "translation",
-                "m",
+                "mm",
                 fast_axis,
             ),
         )
@@ -280,12 +287,12 @@ class NexusWriter:
         )
         create_attributes(
             slow_pixel,
-            ("depends_on", "offset", "transformation_type", "units", "vector"),
+            ("depends_on", "offset_units", "transformation_type", "units", "vector"),
             (
                 "/entry/instrument/detector/module/fast_pixel_direction",
                 offsets[1],
                 "translation",
-                "m",
+                "mm",
                 slow_axis,
             ),
         )
@@ -297,12 +304,18 @@ class NexusWriter:
             module_offset = nxmod.create_dataset("module_offset", data=([0.0]))
             create_attributes(
                 module_offset,
-                ("depends_on", "offset", "transformation_type", "units", "vector"),
+                (
+                    "depends_on",
+                    "offset_units",
+                    "transformation_type",
+                    "units",
+                    "vector",
+                ),
                 (
                     "/entry/instrument/transformations/det_z",
                     offset,
                     "translation",
-                    "m",
+                    "mm",
                     [1, 0, 0],
                 ),
             )
@@ -477,9 +490,12 @@ class NexusWriter:
                 ]
 
     def write(self):
+        # Default fields
+        self._nxs.attrs["default"] = "entry"
+
         # Start writing the NeXus tree
         nxentry = self._nxs.create_group("entry")
-        create_attributes(nxentry, ("NX_class",), ("NXentry",))
+        create_attributes(nxentry, ("NX_class", "default"), ("NXentry", "data"))
 
         # Definition: /entry/definition
         nxentry.create_dataset("definition", data=numpy.string_("NXmx"))
